Programming guide — Pytilities 1.2.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities 1.2.0 documentation »

# Programming guide

Welcome to the user guide of pytilities.

## Introduction

pytilities is a utility library, written in python. It provides various features, with aspect oriented programming capabilities for python being the major feature.

## Guide contents

- Installation instructions
- Importing classes and functions
- Aspect oriented programming tools
- Delegation
- Descriptors

## Not (yet) included in this guide (but included in the API reference)

- Event dispatching
- Function overloading
- Various other features

You may still find the documentation of the older pytilities documentation useful for these subjects, except for delegation as it has changed quite a bit: Old documentation

Some of the unit tests in pytilities.test might be of use as well.

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities 1.2.0 documentation »